// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/stream_event/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_2_0_build_sparc64_src_analyzer_protocol_stream_event_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_2_0_build_sparc64_src_analyzer_protocol_stream_event_events_bif
#define _usr_obj_ports_zeek_8_2_0_build_sparc64_src_analyzer_protocol_stream_event_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr stream_deliver; 
namespace zeek::BifEvent { void enqueue_stream_deliver(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> data);  }
extern zeek::EventHandlerPtr stream_undelivered; 
namespace zeek::BifEvent { void enqueue_stream_undelivered(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek_uint_t seq, zeek_uint_t len);  }

#endif
