// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.2.0/zeek-8.2.0/src/cluster/backend/zeromq/cluster_backend_zeromq.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_2_0_build_sparc64_src_cluster_backend_zeromq_cluster_backend_zeromq_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_2_0_build_sparc64_src_cluster_backend_zeromq_cluster_backend_zeromq_bif
#define _usr_obj_ports_zeek_8_2_0_build_sparc64_src_cluster_backend_zeromq_cluster_backend_zeromq_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc::Cluster::Backend::ZeroMQ { extern zeek::ValPtr spawn_zmq_proxy_thread_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Cluster::Backend::ZeroMQ { extern zeek::ValPtr generate_keypair_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
