// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.2.0/zeek-8.2.0/src/probabilistic/top-k.bif (alternative mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_2_0_build_sparc64_src_probabilistic_top_k_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_2_0_build_sparc64_src_probabilistic_top_k_bif
#define _usr_obj_ports_zeek_8_2_0_build_sparc64_src_probabilistic_top_k_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc { extern zeek::ValPtr topk_init_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_add_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_get_top_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_count_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_epsilon_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_size_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_sum_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_merge_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr topk_merge_prune_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
